#include "mbed.h"
#include "EthernetNetIf.h"
#include "HTTPServer.h"
#include <TextLCD.h>

#if 1    // Star Board Orange
TextLCD lcd(p24, p26, p27, p28, p29, p30);
#else    // GEMMY Card
TextLCD lcd(p11, p12, p27, p28, p29, p30);
#endif

EthernetNetIf eth;
HTTPServer svr;
DigitalOut led1(LED1);
DigitalOut led2(LED2, "led2");
AnalogIn ain(p15,"tmp");
LocalFileSystem fs("webfs");

int main() {
    
    lcd.cls();
    
    printf("Setting up...\n");

    EthernetErr ethErr = eth.setup();

    if(ethErr) {
        printf("Error %d in setup.\n", ethErr);
        lcd.printf("Ether ERR");
        return -1;
    }
    printf("Setup OK\n");
    
    IpAddr addr = eth.getIp();
    lcd.locate(0, 0);
    lcd.printf("%3d.%3d.%3d.%3d", addr[0], addr[1], addr[2], addr[3]);

    FSHandler::mount("/webfs", "/");
    svr.addHandler<RPCHandler>("/rpc");
    svr.addHandler<FSHandler>("/");
    svr.bind(80);

    printf("Listening...\n");

    Timer tm;
    tm.start();

    while(true)
    {
        Net::poll();
        if(tm.read()>.5)
        {
            led1=!led1;
            tm.start();
        }
    }
    return 0;
}